Function finalize_place_commit

fn finalize_place_commit<T: Config<I>, I: 'static>(
    who: &Proprietor<T>,
    reason: &<Pallet<T, I> as Commitment<Proprietor<T>>>::Reason,
    digest: &<Pallet<T, I> as Commitment<Proprietor<T>>>::Digest,
    variant: &<Pallet<T, I> as CommitVariant<Proprietor<T>>>::Position,
    receipt: &CommitInstance<T, I>,
    total_commit: <Pallet<T, I> as InspectAsset<Proprietor<T>>>::Asset,
) -> Result<(), DispatchError>
Low-level helper that centralizes the finalization logic for placing commits.

This function is used across direct, index, and pool digests and serves as the final step of the place a new commit’s operation.

Highly unchecked and assumes all invariants are already validated. Therefore, it is kept private and scoped to this module.