Function finalize_raise_commit

fn finalize_raise_commit<T: Config<I>, I: 'static>(
    who: &Proprietor<T>,
    reason: &<Pallet<T, I> as Commitment<Proprietor<T>>>::Reason,
    receipt: &CommitInstance<T, I>,
    total_raise: <Pallet<T, I> as InspectAsset<Proprietor<T>>>::Asset,
) -> Result<(), DispatchError>
Low-level helper that centralizes the finalization logic for raising commits.

This function is used across direct, index, and pool digests and serves as the final step of the raise an existing commit’s operation.

Highly unchecked and assumes all invariants are already validated. Therefore, it is kept private and scoped to this module.